@@ -1,10 +1,13 @@
+from typing import Callable, Union
+
 from django.contrib import admin
 
 
 class ReadonlyInlineMixin:
     can_delete = False
     show_change_link = True
-    view_on_site = False
+    # Add this type definition to make the type checker happy
+    view_on_site: Union[bool, Callable] = False
     extra = 0
 
     def get_readonly_fields(self, request, obj=None):
